#! /usr/bin/perl -w

# ensure that a given directory exists
sub ensure {
	my ($p) = @_;

	if(!-e $p) {
		mkdir($p);
	}
}

sub to_unix {
	my ($fname) = @_;

	$fname =~ s/\\/\//g;

	return $fname;
}


# split a given string 'some/strange/path/and.file.ext' into 'some/strange/path',
# 'and.file.ext', 'and_file', 'ext'
sub path_name {
	my ($fname) = @_;
	my ($p, $n, $b, $e);
	my $i;

	$fname = to_unix($fname);

	$i = rindex $fname, '/';

	if(0 < $i and $i+1 < length($fname)) {
		$p = substr($fname, 0, $i);
		$n = substr($fname, $i+1);
	}
	else {
		$p = '.';
		$n = $fname;
	}

	$i = rindex $n, '.';
	if(0 < $i and $i+1 < length($n)) {
		$b = substr($n, 0, $i);
		$e = substr($n, $i+1);
	}
	else {
		$b = '.';
		$e = $fname;
	}

	return ($p, $n, $b, $e);
}

# replace some %P, %B, ... in $cmd with the parts constructed from parameter 2
sub repl {
	my ($cmd, $sn) = @_;
	my ($p, $n, $b, $e);

	($p, $n, $b, $e) = path_name($sn);

	$cmd =~ s/\%S/$sn/g;
	$cmd =~ s/\%P/$p/g;
	$cmd =~ s/\%B/$b/g;
	$cmd =~ s/\%E/$e/g;
	$cmd =~ s/\%N/$n/g;

	return $cmd;
}

# return the contents of a file in a string
sub readfile {
    my ($fname) = @_;

    my ($ret, $ors);
    local *FH;

	open FH, "< $fname" or die "can't read-open '$fname'\n";
	binmode FH;
	$sz = -s $fname;
	$ret = '';
	read FH, $ret, $sz;
	close FH;

    return $ret;
}

sub writefile {
    my ($file, $refc) = @_;

    local *FH;

    open(FH, "> $file") or die "$0: can't write-open '$file'\n";
	binmode FH;
	print FH $$refc;
	close FH;
}

sub data_load {
	my ($fname) = @_;

	my ($VAR1, $sz, $cont);
	local *FH;

	open FH, "< $fname" or return undef;
	binmode FH;
	$sz = -s $fname;
	read FH, $cont, $sz;
	close FH;

	eval $cont;
	die "$@" if($@);

	return $VAR1;
}


sub data_save {
	my ($fname, $r_cont) = @_;
	my ($ors);

	my $str = Data::Dumper->Dump([$r_cont], ['VAR1']);

	local *FH;

	$ors = $/;
	undef $/;
	open FH, "> $fname" or die "can't write-open '$fname'\n";
	binmode FH;
	print FH $str;
	close FH;
	$/ = $ors;
}

# add a scalar at the end of an array if it is not already contained in it.
sub add_if_not_in {
	my ($r_a, $n) = @_;
	my ($c);

	foreach $c (@$r_a) {
		if($c eq $n) {
			return;
		}
	}
	push(@$r_a, $n);
}

# Return the index of a Scalar in an Array or -1 if the Array doesn't
# contain the Scalar.
# 1. Param: the Scalar to search for
# 2. Param: Reference to the Array to search in
sub indx {
	my $name = shift;
	my $a_ref = shift;
	my $tmp;
	my $cnt = 0;

	foreach $tmp (@$a_ref) {
		return $cnt if($name eq $tmp);
		$cnt++;
	}

	return -1;
}

# search a file along a path and return the first found occurrence.
# if no file is found return an empty string.
# 1. Param: Reference to the file to search
# 2. Param: Reference to the array of paths
sub find_file {
	my $file_ref = shift;
	my $dir_ref = shift;
	my ($dir, $fname);

	foreach $dir (@$dir_ref) {
		$fname = $dir . '/' . $$file_ref;
		return $fname if(-e $fname);
	}
	return "";
}

1;
